import click

from cli.pmcli import generate_map, validate_file, get_map_generation_status


@click.command()
@click.version_option()
@click.pass_context
@click.argument("file")
@click.argument("nickname")
@click.argument("email")
@click.option("--salt")
@click.option("--token", default=None)
@click.option("--action", type=click.Choice(["validate", "generate", "status"]), required=True)
def main(
        ctx: click.Context,
        file: str,
        nickname: str,
        email: str,
        salt: str,
        action: str,
        token: str | None = None
):
    """
        CLI for validating and generating maps for files using the ProductMap API.
        """
    try:
        if action == "validate":
            result = validate_file(ctx, file, nickname, email, token)
            click.echo(result)
        elif action == "generate":
            result = generate_map(ctx, file, nickname, email, token)
            click.echo(result)
        elif action == "status":
            get_map_generation_status(token, salt)
    except click.ClickException as e:
        ctx.fail(f"Operation failed: {e}")


if __name__ == "__main__":
    main()
